<?xml version="1.0" encoding="iso-8859-1"?>
<!DOCTYPE html [
  <!ENTITY % HTMLlat1 PUBLIC "-//W3C//ENTITIES Latin 1//EN//HTML"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml-lat1.ent">
  %HTMLlat1;
]>
<xsl:stylesheet version="1.0"
 xmlns="http://www.w3.org/1999/xhtml"
 xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
 xmlns:exsl="http://exslt.org/common"
 extension-element-prefixes="exsl">

  <xsl:output method="xml" version="1.0" encoding="iso-8859-1" indent="yes"
   doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
   doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd"/>

  <xsl:strip-space elements="*"/>

  <xsl:param name="index" select="'index.html'"/>
  <xsl:param name="first" select="'slide1.html'"/>

  <xsl:template match="presentation">
    <xsl:param name="this" select="$index"/>
    <xsl:param name="next" select="$first"/>
    <html>
      <head>
	<title><xsl:value-of select="title"/></title>
	<link rel="stylesheet" type="text/css" media="screen" href="slides.css"/>
	<link rel="index" href="{$index}"/>
	<link rel="start" href="{$first}"/>
	<link rel="next" href="{$next}"/>
      </head>
      <body>
	<table border="0" width="100%" cellspacing="0">
	  <!-- navbar -->
	  <tr>
	    <td width="10%" align="left" class="nav">
	      <xsl:text>&nbsp;</xsl:text>
	    </td>
	    <td width="80%" align="center" class="nav">
	      <a href="{$index}"><xsl:value-of select="/presentation/title"/></a>
	    </td>
	    <td width="10%" align="right" class="nav">
	      <xsl:text>&nbsp;</xsl:text>
	      <a href="{$next}">&gt;&gt;</a>
	    </td>
	  </tr>
	  <!-- title -->
	  <tr>
	    <td colspan="3" align="center" class="title">
	      <h1><xsl:value-of select="title"/></h1>
	    </td>
	  </tr>
	  <!-- body -->
	  <tr>
	    <td colspan="3" align="left" class="body">
	      <ol>
		<xsl:apply-templates select="slide" mode="toc"/>
	      </ol>
	    </td>
	  </tr>
	</table>
      </body>
    </html>
    <xsl:apply-templates select="slide"/>
  </xsl:template>

  <xsl:template match="slide" mode="toc">
    <li>
      <a href="{concat('slide', position(), '.html')}">
	<xsl:value-of select="title"/>
      </a>
    </li>
  </xsl:template>

  <xsl:template match="slide">
    <xsl:param name="prev" select="concat('slide', position() - 1, '.html')"/>
    <xsl:param name="this" select="concat('slide', position(), '.html')"/>
    <xsl:param name="next" select="concat('slide', position() + 1, '.html')"/>
    <xsl:param name="last" select="concat('slide', last(), '.html')"/>
    <exsl:document href="{concat('slide', position(), '.html')}"
     method="xml" version="1.0" encoding="iso-8859-1" indent="yes"
     doctype-public="-//W3C//DTD XHTML 1.0 Transitional//EN"
     doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
      <html>
	<head>
	  <title><xsl:value-of select="title"/></title>
	  <link rel="stylesheet" type="text/css" media="screen" href="slides.css"/>
	  <link rel="index" href="{$index}"/>
	  <link rel="start" href="{$first}"/>
	  <xsl:if test="position() != 1">
	    <link rel="prev" href="{$prev}"/>
	  </xsl:if>
	  <xsl:if test="position() != last()">
	    <link rel="next" href="{$next}"/>
	  </xsl:if>
	</head>
	<body>
	  <table border="0" width="100%" cellspacing="0">
	    <!-- navbar -->
	    <tr>
	      <td width="10%" align="left" class="nav">
		<xsl:if test="position() != 1">
		  <a href="{$prev}">&lt;&lt;</a>
		</xsl:if>
		<xsl:text>&nbsp;</xsl:text>
	      </td>
	      <td width="80%" align="center" class="nav">
		<a href="{$index}"><xsl:value-of select="/presentation/title"/></a>
	      </td>
	      <td width="10%" align="right" class="nav">
		<xsl:text>&nbsp;</xsl:text>
		<xsl:if test="position() != last()">
		  <a href="{$next}">&gt;&gt;</a>
		</xsl:if>
	      </td>
	    </tr>
	    <!-- title -->
	    <tr>
	      <td colspan="3" align="center" class="title">
		<h1><xsl:value-of select="title"/></h1>
	      </td>
	    </tr>
	    <!-- body -->
	    <tr>
	      <td colspan="3" align="left" class="body">
		<xsl:apply-templates select="body"/>
	      </td>
	    </tr>
	  </table>
	</body>
      </html>
    </exsl:document>
  </xsl:template>

  <xsl:template match="slide/body">
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="para">
    <p>
      <xsl:apply-templates/>
    </p>
  </xsl:template>

  <xsl:template match="list">
    <ul>
      <xsl:apply-templates/>
    </ul>
  </xsl:template>

  <xsl:template match="list/item">
    <li>
      <xsl:apply-templates/>
    </li>
  </xsl:template>

  <xsl:template match="link">
    <a href="{@href}">
      <xsl:apply-templates/>
    </a>
  </xsl:template>

  <xsl:template match="*" priority="-1">
    <xsl:message terminate="yes">
      <xsl:text>Error: no template for &lt;</xsl:text>
      <xsl:value-of select="name()"/>
      <xsl:text>&gt; element</xsl:text>
    </xsl:message>
  </xsl:template>
</xsl:stylesheet>
